@@ -77,8 +77,8 @@ def VacancyAnalysis():
     for FILE in cfg.paths.defect_inputs:
         if cfg.pipeline.use_geometric_route:
             analyzer = DeformationAnalyzer(
-                cfg.paths.defect_inputs,  
-                cfg.reference.lattice,
+                cfg.paths.defect_inputs[0],
+                cfg.reference.lattice,  
                 cfg.reference.element,
                 threshold=0.02
             )
